#!/usr/bin/rexx
/* Rexx program to test access to the class 'datergf.DateTimeRGF', which is contained
   in the "bsf-rexx-engine.jar" archive; the documentation of the bsf4rexx
   Date/Time classes can be found in the archive "docs_bsf4rexx.zip"

   last change: $Revision: 266 $ $Author: rony $ $Date: 2008-07-19 16:41:58 +0200 (Sat, 19 Jul 2008) $

   license:

    ------------------------ Apache Version 2.0 license -------------------------
       Copyright (C) 2001-2008 Rony G. Flatscher

       Licensed under the Apache License, Version 2.0 (the "License");
       you may not use this file except in compliance with the License.
       You may obtain a copy of the License at

           http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing, software
       distributed under the License is distributed on an "AS IS" BASIS,
       WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
       See the License for the specific language governing permissions and
       limitations under the License.
    -----------------------------------------------------------------------------

    changed: 2008-06-23 rgf, changed code to reflect with the new return string format in
                             the BSF()-function calls (are now prepended with "<O>"
                             (BSFRegistry object) or "<S>" (plain string)
   */

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."


dt_class = "org.oorexx.datergf.DateTimeRGF"

dt1 = bsf("registerBean", "", dt_class) /* create and get a DateTimeRGF object  */
say bsf("invoke", dt1, "toString")      /* show its value                       */

call bsf "invoke", dt1, "update"        /* set to now                           */
say bsf("invoke", dt1, "toString")      /* show the values                      */
say

i=3
say "now sleeping for" i "seconds ..."
call bsf 'sleep', i                     /* sleep i seconds using bsf4rexx       */

call bsf "invoke", dt1, "update"        /* set to now                           */
say bsf("invoke", dt1, "toString")      /* show the values                      */

say
date1 = bsf("getFieldValue", dt1, "date")       /* get DateRGF field            */
say "date-portion:" bsf("invoke", date1,  "toString")

                                        /* determine ISO-week, using a public static
                                           field of the interface "DTC"         */
week=bsf("invoke", date1, "get", bsf("getStaticValue", "org.oorexx.datergf.DTC", "WEEK")  )
say "today falls into ISO-week #" week
say

time1 = bsf("getFieldValue", dt1, "time")       /* get TimeRGF field            */
say "time-portion:" bsf("invoke", time1,  "toString")
say

easter = bsf("invoke", date1, "easter", date1)     /* get Easter sunday for this year      */
week=bsf("invoke", easter, "get", bsf("getStaticValue", "org.oorexx.datergf.DTC", "WEEK")  )
say "This year Easter sunday is:" bsf("invoke", easter, "toString") "which is ISO-week #" week
say

bStrict=random(0, 1)    /* determine which version should be used to create the Java object */
tmp=""
if bStrict then
do
   dLastFebruaryOf2008=bsf('registerBeanStrict', , dt_class, "int", 2008, "int", "3", "int", '0', "int", 1, "int", 2, "int", 3)
   tmp=" with strict data typing!"
end
else
do
   dLastFebruaryOf2008=bsf('registerBean',      , dt_class, 2008, 3, 0, 9, 8, 7)
end

say "Last February in 2008 is:" bsf('invoke', dLastFebruaryOf2008, "toString")
say "     (hint: told to produce 0th March"tmp")"
say "---"
say

say "This demos the Java class 'DateFormatRGF':"
say
say "   the format string being used is:"
say

formatString="'Today is:' [EEEE], d. [MMM] yyyy, 'day #:' D (g 'to go'), hh:mm:ss.SSS [a]"
say formatString
say


df = bsf("registerBean", "", "org.oorexx.datergf.DateFormatRGF")   /* get an instance of the dateformatter */

say bsf("invoke", df, "format", formatString, dt1)
say "   ---"
say "   (now localizing the names of the months and days as well as the 'am/pm')"
call bsf "invoke", df, "localize"
say bsf("invoke", df, "format", formatString, dt1)
say "   the default formatting now produces:" '[' || bsf("invoke", dt1, "toString") || ']'
say "---"
say

locales.1="ITALIAN"
locales.2="FRENCH"
locales.3="UK"
locales.4="US"
locales.5="JAPANESE"
locales.0=5     /* indicate # of elements in stem ("hash")      */

do i=1 to locales.0
   say "trying to get the" locales.i "Locale from Java ("i "of" locales.0") ..."
   call bsf "invoke", df, "localize", bsf("getStaticValue", "java.util.Locale", locales.i)
   say bsf("invoke", df, "format", formatString, dt1)
   say "   the default formatting now produces:" '[' || bsf("invoke", dt1, "toString") || ']'
   say "---"
end

say
say "More on the Java package 'datergf' can be found here or in 'org/orexx/datergf':"
say
say "or check the Internet starting with:"
say
say "   http://www.RexxLA.org"
say "   http://www.ooRexx.org"
